netapp_ontap.models.storage_bridge_errors API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.storage_bridge_errors`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class StorageBridgeErrorsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the StorageBridgeErrors object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `component: StorageBridgeErrorsComponent GET POST PATCH`

    The component field of the storage_bridge_errors.

  `reason: Error GET`

    The reason field of the storage_bridge_errors.

  `severity: str GET POST PATCH`

    Bridge error severity

    Valid choices:

    - unknown
    - notice
    - warning
    - error
  `type: str GET POST PATCH`

    Bridge error type

    Valid choices:

    - unknown
    - bridge_unreachable
    - temp_above_critical_level
    - temp_below_critical_level
    - temp_sensor_status_critical
    - temp_sensor_status_unavailable
    - invalid_configuration
    - sas_port_offline
    - link_failure
    - sas_port_online
    - power_supply_offline